@@ -6,8 +6,9 @@ context("summ")
 set.seed(1)
 output <- rpois(100, 5)
 input <- log(output) + runif(100,0,1)
-fitgf <- glm(output ~ input, family = poisson)
 clusters <- sample(1:5, size = 100, replace = TRUE)
+dat <- as.data.frame(cbind(output, input, clusters))
+fitgf <- glm(output ~ input, data = dat, family = poisson)
 
 # Offset test
 set.seed(100)
@@ -15,11 +16,13 @@ exposures <- rpois(50, 50)
 counts <- exposures - rpois(50, 25)
 money <- (counts/exposures) + rnorm(50, sd = 1)
 talent <- counts*.5 + rnorm(50, sd = 3)
-poisdat <- as.data.frame(cbind(exposures, counts, talent, money))
+wt <- runif(50, 0, 3)
+poisdat <- as.data.frame(cbind(exposures, counts, talent, money, wt))
 pmod <- glm(counts ~ talent*money, offset = log(exposures), data = poisdat,
             family = poisson)
 pmod2 <- glm(counts ~ talent*money + offset(log(exposures)), data = poisdat,
             family = poisson)
+pmodw <- glm(counts ~ talent + money, data = poisdat, weights = wt)
 
 if (requireNamespace("survey")) {
   # survey test
@@ -76,12 +79,38 @@ test_that("jsumm: GLMs w/ offsets work (formula)", {
   expect_is(summ(pmod2, center = TRUE), "summ.glm")
 })
 
+test_that("jsumm: GLMs w/ weights work", {
+  expect_is(summ(pmodw), "summ.glm")
+  expect_is(summ(pmodw, scale = TRUE), "summ.glm")
+  expect_is(summ(pmodw, center = TRUE), "summ.glm")
+})
+
 test_that("jsumm: partial correlations work", {
   expect_is(summ(fit, part.corr = TRUE), "summ.lm")
   expect_output(print(summ(fit, part.corr = TRUE)))
   expect_warning(summ(fit, part.corr = TRUE, robust = TRUE))
 })
 
+# Test handling of singular models
+
+x1 <- rnorm(100)
+x2 <- 2 * x1
+y <- rnorm(100)
+sing_dat <- as.data.frame(cbind(x1, x2, y))
+sing_fit <- lm(y ~ x1 + x2, data = sing_dat)
+sing_fitg <- glm(y ~ x1 + x2, data = sing_dat)
+int_fit <- lm(y ~ 1, data = sing_dat)
+int_fitg <- glm(y ~ 1, data = sing_dat)
+
+test_that("summ handles singular and intercept-only models", {
+  expect_is(summ(sing_fit), "summ.lm")
+  expect_is(summ(sing_fitg), "summ.glm")
+  expect_is(summ(int_fit), "summ.lm")
+  expect_is(summ(int_fitg), "summ.glm")
+})
+
+#### survey tests ###########################################################
+
 if (requireNamespace("survey")) {
   test_that("jsumm: non-linear svyglm models work", {
     expect_is(summ(regmodel), "summ.svyglm")
@@ -106,20 +135,31 @@ if (requireNamespace("survey")) {
   })
 
   test_that("jsumm: svyglm odds ratios", {
-    expect_is(summ(regmodel, odds.ratio = T), "summ.svyglm")
-    expect_output(print(summ(regmodel, odds.ratio = T)))
+    expect_warning(summ(regmodel, odds.ratio = T))
+    expect_is(summ(regmodel, exp = T), "summ.svyglm")
+    expect_output(print(summ(regmodel, exp = T)))
   })
 }
 
+#### lme4 tests #############################################################
+
 if (requireNamespace("lme4")) {
+
+  gm <- glmer(incidence ~ period + (1 | herd), family = poisson, data = cbpp,
+              offset = log(size))
+
   test_that("jsumm: merMod CIs work", {
-    expect_is(summ(mv, confint = TRUE, pvals = FALSE), "summ.merMod")
-    expect_output(print(summ(mv, confint = TRUE, pvals = FALSE)))
+    expect_is(s <- summ(mv, confint = TRUE), "summ.merMod")
+    expect_output(print(s))
+    expect_is(s <- summ(gm, confint = TRUE), "summ.merMod")
+    expect_output(print(s))
   })
 
   test_that("jsumm: merMod dropping pvals works", {
-    expect_is(summ(mv, pvals = FALSE), "summ.merMod")
+    expect_is(s <- summ(mv, pvals = FALSE), "summ.merMod")
     expect_output(print(summ(mv, pvals = FALSE)))
+    expect_is(s <- summ(gm, pvals = FALSE), "summ.merMod")
+    expect_output(print(s))
   })
 
   test_that("jsumm and merMod objects: everything works", {
@@ -129,11 +169,6 @@ if (requireNamespace("lme4")) {
     expect_warning(summ(mv, robust = TRUE))
   })
 
-  test_that("summ.merMod: r.squared works", {
-    skip_on_cran()
-    expect_is(j <- summ(mv, pvals = FALSE, r.squared = TRUE), "summ.merMod")
-    expect_output(print(j))
-  })
 }
 
 test_that("jsumm: lm CIs work", {
@@ -167,14 +202,14 @@ test_that("jsumm and center_lm: centering works", {
 })
 
 test_that("jsumm can scale weighted lms", {
-  expect_is(summ(fitw, scale = T, n.sd = 2, robust = TRUE), "summ.lm")
-  expect_is(summ(fitw, center = T, robust = TRUE), "summ.lm")
+  expect_is(summ(fitw, scale = T, n.sd = 2, robust = "HC3"), "summ.lm")
+  expect_is(summ(fitw, center = T, robust = "HC3"), "summ.lm")
 })
 
 test_that("jsumm: lm robust SEs work", {
   expect_is(summ(fit, robust = T), "summ.lm")
-  expect_is(summ(fit, robust = T, robust.type = "HC4m"), "summ.lm")
-  expect_output(print(summ(fit, robust = T, robust.type = "HC4m")))
+  expect_is(summ(fit, robust = "HC4m"), "summ.lm")
+  expect_output(print(summ(fit, robust = "HC4m")))
 })
 
 test_that("jsumm: lm partial corrs works", {
@@ -183,31 +218,28 @@ test_that("jsumm: lm partial corrs works", {
 })
 
 test_that("jsumm: warn with partial corrs and robust SEs", {
-  expect_warning(summ(fit, robust = T, part.corr = T))
+  expect_warning(summ(fit, robust = "HC3", part.corr = T))
 })
 
 test_that("jsumm: glm robust SEs work", {
-  expect_is(summ(fitgf, robust = T), "summ.glm")
-  expect_is(summ(fitgf, robust = T, robust.type = "HC4m"), "summ.glm")
-  expect_output(print(summ(fitgf, robust = T, robust.type = "HC4m")))
+  expect_is(summ(fitgf, robust = "HC3"), "summ.glm")
+  expect_output(print(summ(fitgf, robust = "HC4m")))
 })
 
 test_that("jsumm: lm cluster-robust SEs work", {
-  expect_is(summ(fit, robust = T, cluster = "Population"), "summ.lm")
-  expect_output(print(summ(fit, robust = T, cluster = "Population")))
-  expect_error(summ(fit, robust = T, robust.type = "HC4m",
-                        cluster = "Population"))
+  expect_is(summ(fit, robust = "HC3", cluster = "Population"), "summ.lm")
+  expect_output(print(summ(fit, robust = "HC3", cluster = "Population")))
+  expect_error(summ(fit, robust = "HC4m", cluster = "Population"))
 })
 
 test_that("jsumm: glm cluster-robust SEs work", {
-  expect_is(summ(fitgf, robust = T, cluster = clusters), "summ.glm")
+  expect_is(summ(fitgf, robust = "HC3", cluster = clusters), "summ.glm")
   expect_output(print(summ(fitgf, robust = T, cluster = clusters)))
-  expect_error(summ(fitgf, robust = T, robust.type = "HC4m",
-                        cluster = clusters))
+  expect_error(summ(fitgf, robust = "HC4m", cluster = clusters))
 })
 
 test_that("jsumm: Printing isn't borked", {
-  expect_output(print(summ(fitgf, vifs = TRUE)))
+  expect_error(print(summ(fitgf, vifs = TRUE, robust = TRUE)))
   expect_output(print(summ(fitgf, scale = TRUE)))
   if (requireNamespace("survey")) {
     expect_output(print(summ(regmodel, scale = TRUE, n.sd = 2)))
@@ -223,17 +255,27 @@ test_that("jsumm: Printing isn't borked", {
 
 })
 
-test_that("jsumm: summ.default", {
-  expect_is(jtools:::summ.default(fit), "summ.default")
-  expect_is(jtools:::summ.default(fit, robust = T, scale = T),
-            "summ.default")
-  if (requireNamespace("survey")) {
-    expect_is(jtools:::summ.default(regmodel, center = T), "summ.default")
-    expect_is(jtools:::summ.default(regmodel, confint = T), "summ.default")
-    expect_output(print(jtools:::summ.default(regmodel, center = T)))
-    expect_output(print(jtools:::summ.default(regmodel, confint = T)))
-  }
-  expect_output(print(jtools:::summ.default(fit)))
-  expect_output(print(jtools:::summ.default(fit, robust = T, scale = T)))
+#### defaults test ##########################################################
+
+set_summ_defaults(digits = 4, model.info = FALSE,
+                 model.fit = FALSE, pvals = FALSE, robust = TRUE,
+                 confint = TRUE, ci.width = .90, vifs = TRUE)
+
+test_that("set_summ_defaults changes options", {
+
+  expect_equal(getOption("jtools-digits"), 4)
+  expect_equal(getOption("summ-model.info"), FALSE)
+  expect_equal(getOption("summ-model.fit"), FALSE)
+  expect_equal(getOption("summ-pvals"), FALSE)
+  expect_equal(getOption("summ-robust"), TRUE)
+  expect_equal(getOption("summ-confint"), TRUE)
+  expect_equal(getOption("summ-ci.width"), .90)
+  expect_equal(getOption("summ-vifs"), TRUE)
 
 })
+
+# Set all back to NULL
+set_summ_defaults(digits = NULL, model.info = NULL,
+                 model.fit = NULL, pvals = NULL, robust = NULL,
+                 confint = NULL, ci.width = NULL, vifs = NULL)
+
